==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/apcas/v20201127/models/QueryGeneralStatRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.apcas.v20201127.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class QueryGeneralStatRequest extends AbstractModel{

    /**
    * 请求类型:1,人群特征洞察统计 2购车意向预测统计
    */
    @SerializedName("Type")
    @Expose
    private Long Type;

    /**
     * Get 请求类型:1,人群特征洞察统计 2购车意向预测统计 
     * @return Type 请求类型:1,人群特征洞察统计 2购车意向预测统计
     */
    public Long getType() {
        return this.Type;
    }

    /**
     * Set 请求类型:1,人群特征洞察统计 2购车意向预测统计
     * @param Type 请求类型:1,人群特征洞察统计 2购车意向预测统计
     */
    public void setType(Long Type) {
        this.Type = Type;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);

    }
}

==> tencentcloud-sdk-java-3.1.310-sources.jar: com/tencentcloudapi/apcas/v20201127/models/QueryGeneralStatRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.apcas.v20201127.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class QueryGeneralStatRequest extends AbstractModel{

    /**
    * 请求类型:1,人群特征洞察统计 2购车意向预测统计
    */
    @SerializedName("Type")
    @Expose
    private Long Type;

    /**
     * Get 请求类型:1,人群特征洞察统计 2购车意向预测统计 
     * @return Type 请求类型:1,人群特征洞察统计 2购车意向预测统计
     */
    public Long getType() {
        return this.Type;
    }

    /**
     * Set 请求类型:1,人群特征洞察统计 2购车意向预测统计
     * @param Type 请求类型:1,人群特征洞察统计 2购车意向预测统计
     */
    public void setType(Long Type) {
        this.Type = Type;
    }

    public QueryGeneralStatRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public QueryGeneralStatRequest(QueryGeneralStatRequest source) {
        if (source.Type != null) {
            this.Type = new Long(source.Type);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);

    }
}
